@@ -9,7 +9,7 @@ import os
 from contextualized_topic_models.models.kitty_classifier import Kitty
 import pytest
 import nltk
-
+import numpy as np
 
 nltk.download("stopwords")
 
@@ -32,7 +32,7 @@ def test_labels_set(data_dir):
 
     tp = TopicModelDataPreparation("distiluse-base-multilingual-cased")
 
-    training_dataset = tp.fit(data[:100], data[:100], labels[:100])
+    training_dataset = tp.fit(data[:100], data[:100], labels=labels[:100])
 
     ctm = CombinedTM(reduce_on_plateau=True, solver='sgd', bow_size=len(tp.vocab),
                      contextual_size=512, num_epochs=1, n_components=5, batch_size=2, label_size=len(set(labels[:100])))
@@ -57,6 +57,22 @@ def test_kitty(data_dir):
     kt.pretty_print_word_classes()
 
 
+def test_custom_embeddings(data_dir):
+
+    with open(data_dir + "/custom_embeddings/sample_text.txt") as filino:
+        training = filino.read().splitlines()
+
+    embeddings = np.load(data_dir + "/custom_embeddings/sample_embeddings.npy")
+
+    turkish_stopwords = nltk.corpus.stopwords.words('turkish')
+
+    kt = Kitty()
+    kt.train(training, custom_embeddings=embeddings, topics=5, epochs=1,
+             stopwords_list=turkish_stopwords, hidden_sizes=(200, 200))
+
+    kt.get_ldavis_data_format()
+
+
 def test_validation_set(data_dir):
 
     with open(data_dir + '/gnews/GoogleNews.txt') as filino:
@@ -115,7 +131,7 @@ def test_training_all_classes_ctm(data_dir):
 def test_preprocessing(data_dir):
     docs = [line.strip() for line in open(data_dir + "gnews/GoogleNews.txt", 'r').readlines()]
     sp = WhiteSpacePreprocessing(docs, "english")
-    prep_corpus, unprepr_corpus, vocab = sp.preprocess()
+    prep_corpus, unprepr_corpus, vocab, retained_indices = sp.preprocess()
 
     assert len(prep_corpus) == len(unprepr_corpus)  # prep docs must have the same size as the unprep docs
     assert len(prep_corpus) <= len(docs)  # preprocessed docs must be less than or equal the original docs
